@@ -180,6 +180,7 @@ _get_date_time_format()
   }
   return format;
 }
+
 const gchar*
 _get_secondary_text_color()
 {
@@ -409,14 +410,14 @@ _get_contact_attribute_icon(ScoutWindow* self, const gchar* attribute)
 						HILDON_ICON_PIXEL_SIZE_SMALL, GTK_ICON_LOOKUP_NO_SVG, NULL);
       
     }
-    if(g_strcmp0(attribute, EVC_FN)==0)
+    else if(g_strcmp0(attribute, EVC_FN)==0)
     {
       attribute_icon = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
 					     "general_business_card",
 						HILDON_ICON_PIXEL_SIZE_SMALL, GTK_ICON_LOOKUP_NO_SVG, NULL);
       
     }
-    if(g_strcmp0(attribute, EVC_N)==0)
+    else if(g_strcmp0(attribute, EVC_N)==0)
     {
       attribute_icon = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
 						"general_business_card",
@@ -463,7 +464,8 @@ _get_contact_attribute_icon(ScoutWindow* self, const gchar* attribute)
 	
 	if (!icon_name)
 	  icon_name = mc_profile_get_icon_name (mc_profile);
-	g_object_unref (mc_profile);	
+	g_object_unref (mc_profile);
+
 	if(!icon_name)
 	{
 	  return NULL;
@@ -509,7 +511,7 @@ _get_account_icon(ScoutWindow* self, const gchar* account_uid)
 	if (!icon_name)
 	  icon_name = mc_profile_get_icon_name (profile);
 	
-	g_object_unref (profile);
+	g_object_unref(profile);
 	
 	if(icon_name)
 	{
@@ -524,8 +526,6 @@ _get_account_icon(ScoutWindow* self, const gchar* account_uid)
       g_hash_table_insert(self->priv->cached_account_icon,
 			  g_strdup(account_uid),
 			  account_icon);
-      
-    
   }
   return account_icon;
 }
@@ -567,7 +567,6 @@ _get_contact_avatar_icon(ScoutWindow* self, const gchar* abook_uid)
     g_hash_table_insert(self->priv->cached_contact_avatar,
 			g_strdup(abook_uid),
 			avatar_icon);
-    g_object_ref(avatar_icon);
   }
   return avatar_icon;
 }
@@ -856,7 +855,6 @@ _find_and_insert_calendar_event(ScoutWindow* self, CComponent* component, int ca
     const gchar* faulty_char = NULL;
     if(!g_utf8_validate(component->getSummary().c_str(), -1, &faulty_char))
     {
-      g_warning("not valid %s\n", component->getSummary().c_str());
       title_text = g_strndup(component->getSummary().c_str(),
 			     faulty_char - component->getSummary().c_str());
     }
@@ -948,10 +946,10 @@ static gboolean
 _search_and_insert_contact_attribute(ScoutWindow* self, OssoABookContact* contact, const gchar* e_contact_field)
 {
   GList* attributes = osso_abook_contact_get_attributes(E_CONTACT(contact), e_contact_field);
-  for(;attributes;attributes=attributes->next)
+  for(GList* attribute = attributes;attribute;attribute=attribute->next)
   {
-    GList* values = e_vcard_attribute_get_values((EVCardAttribute*)attributes->data);
-    const gchar* name = e_vcard_attribute_get_name((EVCardAttribute*)attributes->data);
+    GList* values = e_vcard_attribute_get_values((EVCardAttribute*)attribute->data);
+    const gchar* name = e_vcard_attribute_get_name((EVCardAttribute*)attribute->data);
     const gchar* value = NULL;
     gchar* prefix = NULL;
     gchar* suffix = NULL;
@@ -987,6 +985,7 @@ _search_and_insert_contact_attribute(ScoutWindow* self, OssoABookContact* contac
       return true;
     }
   }
+  g_list_free(attributes);
   return false;
 }
 
@@ -1617,7 +1616,7 @@ _init_menu(ScoutWindow* self)
   HildonAppMenu* menu;
   menu = HILDON_APP_MENU(hildon_app_menu_new());
   GtkWidget* settings_button = hildon_gtk_button_new(HILDON_SIZE_FINGER_HEIGHT);
-  gtk_button_set_label(GTK_BUTTON(settings_button), "settings");
+  gtk_button_set_label(GTK_BUTTON(settings_button), "Settings");
   g_signal_connect(settings_button, "clicked", G_CALLBACK(_show_settings_dialog_cb), self);
   hildon_app_menu_append(menu, GTK_BUTTON(settings_button));
   gtk_widget_show_all(GTK_WIDGET(menu));
